/**
 * @file stringifyPosition
 * @module unist-util-stringify-position/stringifyPosition
 */
import type { Info, Options } from './types/index.mjs';
/**
 * Serialize the positional info of a node, point, position, or range.
 *
 * The serialized info is returned in one the following formats:
 *
 *  - `ls:cs-le:ce, os-oe` (node, position, range)
 *  - `ls:cs-le:ce` (node, position, range)
 *  - `l:c` (point)
 *
 * where `l` stands for line, `c` for column, `o` for offset, `s` for `start`,
 * and `e` for end.
 *
 * An empty string (`''`) is returned if the given info is neither a node,
 * point, position, or range.
 *
 * @see {@linkcode Info}
 * @see {@linkcode Options}
 *
 * @param {(Info | null)?} [info] - Node, point, position, or range
 * @param {(Options | null)?} [options] - Configuration options
 * @param {(boolean | null)?} [options.offsets=false] - Serialize offsets if
 * `info` is a node, position, or range
 * @return {string} Pretty printed positional info
 */
declare function stringifyPosition(info?: Info | null, options?: Options | null): string;
/**
 * Serialize the positional info of a node, point, position, or range.
 *
 * The serialized info is returned in one the following formats:
 *
 *  - `ls:cs-le:ce, os-oe` (node, position, range)
 *  - `ls:cs-le:ce` (node, position, range)
 *  - `l:c` (point)
 *
 * where `l` stands for line, `c` for column, `o` for offset, `s` for `start`,
 * and `e` for end.
 *
 * An empty string (`''`) is returned if the given info is neither a node,
 * point, position, or range.
 *
 * @see {@linkcode Options}
 *
 * @param {unknown?} [info] - Node, point, position, or range
 * @param {(Options | null)?} [options] - Configuration options
 * @param {(boolean | null)?} [options.offsets=false] - Serialize offsets if
 * `info` is a node, position, or range
 * @return {string} Pretty printed positional info
 */
declare function stringifyPosition(info?: unknown, options?: Options | null): string;
export default stringifyPosition;
